==> nextcloud-22.1.1.tgz: nextcloud/apps/federatedfilesharing/l10n/es_AR.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea agregar el elemento compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Elemento compartido remoto",
    "Remote share password" : "Contraseña del elemento compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Agregar elemento compartido remoto",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "El ID de la Nube Federada es inválido",
    "Server to server sharing is not enabled on this server" : "Compartir de servidor a servidor no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No fue posible establecer el elemento compartido federado. ",
    "Couldn't establish a federated share, maybe the password was wrong." : "No fue posible establecer el elemento compartido federado, tal vez la contraseña sea incorrecta. ",
    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
    "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "Federated sharing" : "Elementos compartidos federados",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Usted ha recibido {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Usted recibió {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud, ver %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Sharing" : "Compartiendo",
    "Federated file sharing" : "Compartir archivos en federación",
    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
    "Open documentation" : "Abrir documentación",
    "Allow users on this server to receive shares from other servers" : "Permitir que los usuarios de este servidor recibir elementos compartidos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
    "Allow users to publish their data to a global and public address book" : "Permitir a los usuarios publicar sus datos a una libreta de direcciones global y pública",
    "Federated Cloud" : "Nube Federada",
    "Your Federated Cloud ID:" : "Su ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártalo para que sus amigos puedan compartir archivos con usted. ",
    "Add to your website" : "Agregar a su sitio web",
    "Share with me via Nextcloud" : "Compartir conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Adjust how people can share between servers." : "Ajustar cómo las personas pueden compartir entre servidores. "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.5.tgz: nextcloud/apps/federatedfilesharing/l10n/es_AR.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea agregar el elemento compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Elemento compartido remoto",
    "Remote share password" : "Contraseña del elemento compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Agregar elemento compartido remoto",
    "Invalid Federated Cloud ID" : "El ID de la Nube Federada es inválido",
    "Server to server sharing is not enabled on this server" : "Compartir de servidor a servidor no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No fue posible establecer el elemento compartido federado. ",
    "Couldn't establish a federated share, maybe the password was wrong." : "No fue posible establecer el elemento compartido federado, tal vez la contraseña sea incorrecta. ",
    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
    "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "Federated sharing" : "Elementos compartidos federados",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Usted ha recibido {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Usted recibió {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud, ver %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Sharing" : "Compartiendo",
    "Federated file sharing" : "Compartir archivos en federación",
    "Allow users on this server to receive shares from other servers" : "Permitir que los usuarios de este servidor recibir elementos compartidos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
    "Allow users to publish their data to a global and public address book" : "Permitir a los usuarios publicar sus datos a una libreta de direcciones global y pública",
    "Federated Cloud" : "Nube Federada",
    "Your Federated Cloud ID:" : "Su ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártalo para que sus amigos puedan compartir archivos con usted. ",
    "Twitter" : "Twitter",
    "Add to your website" : "Agregar a su sitio web",
    "Share with me via Nextcloud" : "Compartir conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
    "Open documentation" : "Abrir documentación",
    "Adjust how people can share between servers." : "Ajustar cómo las personas pueden compartir entre servidores. "
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
